@@ -283,7 +283,7 @@ end do
 if(maxval(fmodel).gt.1) then
   ibeta_AM=0
   if (verbose.eq.1) then
-    call dblepr('Initializing MCMC parameters ...',-1,1.d0,0)
+    call piprint()
   end if
   do imodmet=1,maxmodmet
     imodmetg=imodmet
@@ -453,7 +453,7 @@ beta_mAM(:,1)=beta
 do imcmc=1,nmcmc
   if(imcmc.eq.1) then
     if (verbose.eq.1) then
-      call dblepr('Burnin ...',-1,1.d0,0)
+      call biprint()
     end if
     pmet=0
   end if
@@ -467,7 +467,7 @@ do imcmc=1,nmcmc
           call aprint(ifun, dble(pmet(ifun))/dble(nblow))
         end if
       end do
-      call dblepr('Main iterations ...',-1,1.d0,0)
+      call miprint()
     end if
     pmet=0
   end if
